init

Function init 

pub fn init<R: Runtime>() -> TauriPlugin<R>
Initialize the tauri-hasgard plugin.

On non-Unix, non-Windows platforms or in release builds, returns a no-op plugin. In debug builds on Unix, injects the JS bridge, stores an EvalEngine, and starts a Unix socket server at TAURI_HASGARD_SOCKET when set, otherwise at $XDG_RUNTIME_DIR/tauri-hasgard-{identifier}.sock. In debug builds on Windows, starts a Named Pipe server at \\.\pipe\tauri-hasgard-{identifier} and registers the instance under %LOCALAPPDATA%\tauri-hasgard\instances\.